/** @typedef {import('@vue/cli/lib/GeneratorAPI')} GeneratorAPI */

/**
 * @param {GeneratorAPI} api
 * @param {any} options
 */
module.exports = (api, options) => {
  api.extendPackage({
    devDependencies: {
      tailwindcss: '^0.6.6',
      'postcss-import': '^12.0.0',
      'postcss-nested': '^4.1.0',
      '@fullhuman/postcss-purgecss': '^1.1.0'
    }
  })

  api.injectImports(api.entryFile, `import './styles/main.css'`)

  api.render('./template')

  api.onCreateComplete(() => {
    const fs = require('fs')
    const postcssPath = api.resolve('./postcss.config.js')
    const content = fs.readFileSync(postcssPath, { encoding: 'utf-8' })
    const lines = content.split(/\r?\n/g)
    const pluginsIndex = lines.findIndex(line => line.match(/plugins/))

    const newLines = [
      `...process.env.NODE_ENV === 'production' ? [`,
      `  require('@fullhuman/postcss-purgecss')({`,
      `    content: ['./src/**/*.vue', './public/**/*.html'],`,
      `    extractors: [`,
      `      {`,
      `        extractor: class {`,
      `          static extract(content) {`,
      `            return content.match(/[a-zA-Z0-9-:_/]+/g) || [];`,
      `          }`,
      `       },`,
      `        extensions: ['vue', 'html'],`,
      `      },`,
      `    ],`,
      `  })`,
      `] : [],`,
      `'postcss-import': {},`,
      `'postcss-nested': {},`,
      `tailwindcss: './tailwind.js',`
    ]

    newLines.forEach((line, index) => {
      const newIndex = pluginsIndex + index + 1
      lines.splice(newIndex, 0, `    ${line}`)
    })

    fs.writeFileSync(postcssPath, lines.join('\r\n'), { encoding: 'utf-8' })
  })
}
